==> openshift-model-console-5.11.1-sources.jar: io/fabric8/openshift/api/model/console/v1alpha1/ConsolePluginProxyServiceFluentImpl.java <==
package io.fabric8.openshift.api.model.console.v1alpha1;

import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class ConsolePluginProxyServiceFluentImpl<A extends io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceFluent<A>{
  public ConsolePluginProxyServiceFluentImpl() {
  }
  public ConsolePluginProxyServiceFluentImpl(io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyService instance) {
    this.withAuthorize(instance.getAuthorize()); 
    this.withCaCertificate(instance.getCaCertificate()); 
    this.withName(instance.getName()); 
    this.withNamespace(instance.getNamespace()); 
    this.withPort(instance.getPort()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.Boolean authorize;
  private java.lang.String caCertificate;
  private java.lang.String name;
  private java.lang.String namespace;
  private java.lang.Integer port;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.Boolean getAuthorize() {
    return this.authorize;
  }
  public A withAuthorize(java.lang.Boolean authorize) {
    this.authorize=authorize; return (A) this;
  }
  public java.lang.Boolean hasAuthorize() {
    return this.authorize != null;
  }
  public java.lang.String getCaCertificate() {
    return this.caCertificate;
  }
  public A withCaCertificate(java.lang.String caCertificate) {
    this.caCertificate=caCertificate; return (A) this;
  }
  public java.lang.Boolean hasCaCertificate() {
    return this.caCertificate != null;
  }
  
  /**
   * Method is deprecated. use withCaCertificate instead.
   */
  @java.lang.Deprecated
  public A withNewCaCertificate(java.lang.String arg0) {
    return (A)withCaCertificate(new String(arg0));
  }
  public java.lang.String getName() {
    return this.name;
  }
  public A withName(java.lang.String name) {
    this.name=name; return (A) this;
  }
  public java.lang.Boolean hasName() {
    return this.name != null;
  }
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0) {
    return (A)withName(new String(arg0));
  }
  public java.lang.String getNamespace() {
    return this.namespace;
  }
  public A withNamespace(java.lang.String namespace) {
    this.namespace=namespace; return (A) this;
  }
  public java.lang.Boolean hasNamespace() {
    return this.namespace != null;
  }
  
  /**
   * Method is deprecated. use withNamespace instead.
   */
  @java.lang.Deprecated
  public A withNewNamespace(java.lang.String arg0) {
    return (A)withNamespace(new String(arg0));
  }
  public java.lang.Integer getPort() {
    return this.port;
  }
  public A withPort(java.lang.Integer port) {
    this.port=port; return (A) this;
  }
  public java.lang.Boolean hasPort() {
    return this.port != null;
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ConsolePluginProxyServiceFluentImpl that = (ConsolePluginProxyServiceFluentImpl) o;
    if (authorize != null ? !authorize.equals(that.authorize) :that.authorize != null) return false;
    if (caCertificate != null ? !caCertificate.equals(that.caCertificate) :that.caCertificate != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (namespace != null ? !namespace.equals(that.namespace) :that.namespace != null) return false;
    if (port != null ? !port.equals(that.port) :that.port != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(authorize,  caCertificate,  name,  namespace,  port,  additionalProperties,  super.hashCode());
  }
  
}

==> openshift-model-console-5.12.4-sources.jar: io/fabric8/openshift/api/model/console/v1alpha1/ConsolePluginProxyServiceFluentImpl.java <==
package io.fabric8.openshift.api.model.console.v1alpha1;

import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class ConsolePluginProxyServiceFluentImpl<A extends io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyServiceFluent<A>{
  public ConsolePluginProxyServiceFluentImpl() {
  }
  public ConsolePluginProxyServiceFluentImpl(io.fabric8.openshift.api.model.console.v1alpha1.ConsolePluginProxyService instance) {
    this.withAuthorize(instance.getAuthorize()); 
    this.withCaCertificate(instance.getCaCertificate()); 
    this.withName(instance.getName()); 
    this.withNamespace(instance.getNamespace()); 
    this.withPort(instance.getPort()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.Boolean authorize;
  private java.lang.String caCertificate;
  private java.lang.String name;
  private java.lang.String namespace;
  private java.lang.Integer port;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.Boolean getAuthorize() {
    return this.authorize;
  }
  public A withAuthorize(java.lang.Boolean authorize) {
    this.authorize=authorize; return (A) this;
  }
  public java.lang.Boolean hasAuthorize() {
    return this.authorize != null;
  }
  public java.lang.String getCaCertificate() {
    return this.caCertificate;
  }
  public A withCaCertificate(java.lang.String caCertificate) {
    this.caCertificate=caCertificate; return (A) this;
  }
  public java.lang.Boolean hasCaCertificate() {
    return this.caCertificate != null;
  }
  
  /**
   * Method is deprecated. use withCaCertificate instead.
   */
  @java.lang.Deprecated
  public A withNewCaCertificate(java.lang.String arg0) {
    return (A)withCaCertificate(new String(arg0));
  }
  public java.lang.String getName() {
    return this.name;
  }
  public A withName(java.lang.String name) {
    this.name=name; return (A) this;
  }
  public java.lang.Boolean hasName() {
    return this.name != null;
  }
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0) {
    return (A)withName(new String(arg0));
  }
  public java.lang.String getNamespace() {
    return this.namespace;
  }
  public A withNamespace(java.lang.String namespace) {
    this.namespace=namespace; return (A) this;
  }
  public java.lang.Boolean hasNamespace() {
    return this.namespace != null;
  }
  
  /**
   * Method is deprecated. use withNamespace instead.
   */
  @java.lang.Deprecated
  public A withNewNamespace(java.lang.String arg0) {
    return (A)withNamespace(new String(arg0));
  }
  public java.lang.Integer getPort() {
    return this.port;
  }
  public A withPort(java.lang.Integer port) {
    this.port=port; return (A) this;
  }
  public java.lang.Boolean hasPort() {
    return this.port != null;
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ConsolePluginProxyServiceFluentImpl that = (ConsolePluginProxyServiceFluentImpl) o;
    if (authorize != null ? !authorize.equals(that.authorize) :that.authorize != null) return false;
    if (caCertificate != null ? !caCertificate.equals(that.caCertificate) :that.caCertificate != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (namespace != null ? !namespace.equals(that.namespace) :that.namespace != null) return false;
    if (port != null ? !port.equals(that.port) :that.port != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(authorize,  caCertificate,  name,  namespace,  port,  additionalProperties,  super.hashCode());
  }
  
}
